==> knights-trinity-14.0.6.tar.xz: knights-trinity-14.0.6/knights/dlg_selectemail.cpp <==
/***************************************************************************
                          dlg_selectemail.cpp  -  description
                             -------------------
    begin                : Sun Oct 27 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dlg_selectemail.moc"
#include <tqvbox.h>
#include <tqlineedit.h>
#include "resource.h"

dlg_selectemail::dlg_selectemail(TQWidget *parent, resource *Rsrc ) :
	KDialogBase(	parent,
								0,
								TRUE,
								i18n("Select Email Address"),
								Help|Ok,
								Ok,
								TRUE )
{
	myResource = Rsrc;
	BOX_Parent = makeVBoxMainWidget();

	EDIT_Email = new TQLineEdit( BOX_Parent );
	EDIT_Email->setText( myResource->Email_Address );
	connect( EDIT_Email, TQT_SIGNAL( returnPressed() ), this, TQT_SLOT( changeValue() ) );
}
dlg_selectemail::~dlg_selectemail()
{
}
void dlg_selectemail::changeValue( void )
{
	myResource->Email_Address = EDIT_Email->text();
	emit valuesChanged();
}

==> knights-trinity-14.1.2.tar.xz: knights-trinity-14.1.2/knights/dlg_selectemail.cpp <==
/***************************************************************************
                          dlg_selectemail.cpp  -  description
                             -------------------
    begin                : Sun Oct 27 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dlg_selectemail.moc"
#include <tqvbox.h>
#include <tqlineedit.h>
#include "resource.h"

dlg_selectemail::dlg_selectemail(TQWidget *parent, resource *Rsrc ) :
	KDialogBase(	parent,
								0,
								TRUE,
								i18n("Select Email Address"),
								Help|Ok,
								Ok,
								TRUE )
{
	myResource = Rsrc;
	BOX_Parent = makeVBoxMainWidget();

	EDIT_Email = new TQLineEdit( BOX_Parent );
	EDIT_Email->setText( myResource->Email_Address );
	connect( EDIT_Email, TQ_SIGNAL( returnPressed() ), this, TQ_SLOT( changeValue() ) );
}
dlg_selectemail::~dlg_selectemail()
{
}
void dlg_selectemail::changeValue( void )
{
	myResource->Email_Address = EDIT_Email->text();
	emit valuesChanged();
}
